@@ -1,19 +1,19 @@
 import os
 import sys
-import re
 
+from .utils import get_git_user, get_translator
 
-from .utils import get_translator
-from .utils import get_git_user
 _ = get_translator()
 
-HOOKS_DIR = ".git/hooks"
-HOOK_NAME = "commit-msg"
+HOOKS_DIR = '.git/hooks'
+HOOK_NAME = 'commit-msg'
 HOOK_PATH = os.path.join(HOOKS_DIR, HOOK_NAME)
 GIT_USER = get_git_user()
 
 # Expressão regular para validar commits convencionais
-COMMIT_REGEX = r"^(feat|fix|chore|refactor|test|docs|style|ci|perf)(\(.+\))?: .{1,72}$"
+COMMIT_REGEX = (
+    r'^(feat|fix|chore|refactor|test|docs|style|ci|perf)(\(.+\))?: .{1,72}$'
+)
 
 types = """
 build: Changes that affect the build system or external dependencies (example scopes: gulp, broccoli, npm)
@@ -25,9 +25,8 @@ perf: A code change that improves performance
 refactor: A code change that neither fixes a bug nor adds a feature
 style: Changes that do not affect the meaning of the code (white-space, formatting, missing semi-colons, etc)
 test: Adding missing tests or correcting existing tests
-"""
-HOOK_SCRIPT = (
-    f"""#!/bin/sh
+"""  # noqa: E501
+HOOK_SCRIPT = f"""#!/bin/sh
     COMMIT_MSG_FILE=$1
     COMMIT_MSG=$(cat "$COMMIT_MSG_FILE")
 
@@ -37,7 +36,7 @@ HOOK_SCRIPT = (
         echo "Example: feat(core): Add new functionality"
         exit 1
     fi
-    
+
     GIT_USER=$(git config --get user.name)
     [ -z "$GIT_USER" ] && GIT_USER="Unknown User"
 
@@ -48,9 +47,8 @@ HOOK_SCRIPT = (
     if echo "$CURRENT_BRANCH" | grep -Eq "^(feature|hotfix|release)/"; then
         echo "\nCo-authored-by: $GIT_USER" >> "$COMMIT_MSG_FILE"
     fi
-    
+
     """
-)
 
 
 def setup_git_hook():
@@ -58,15 +56,13 @@ def setup_git_hook():
     if not os.path.exists(HOOKS_DIR):
         print(
             _(
-                "❌ .git/hooks directory not found. Please run inside a Git repository."  # noqa: E501
+                '❌ .git/hooks directory not found. Please run inside a Git repository.'  # noqa: E501
             )
         )
         sys.exit(1)
 
-    with open(HOOK_PATH, "w") as hook_file:
+    with open(HOOK_PATH, 'w', encoding='utf-8') as hook_file:
         hook_file.write(HOOK_SCRIPT)
 
     os.chmod(HOOK_PATH, 0o755)  # Torna o hook executável
-    print(
-        _("✅ Commit-msg hook successfully configured!")
-    )
+    print(_('✅ Commit-msg hook successfully configured!'))
